@@ -15,6 +15,7 @@ from .tools import exec_file_in_path
 from .cli import cli, pass_config, Commands
 from .lib_clickhelpers import AliasedGroup
 from .tools import __hash_odoo_password
+from .tools import _make_sure_module_is_installed
 
 
 @cli.group(cls=AliasedGroup)
@@ -61,7 +62,8 @@ def pgactivity(config):
     conn = DBConnection(
         config.dbname, config.db_host, config.db_port, config.db_user, config.db_pwd
     )
-    __dcrun(config, 
+    __dcrun(
+        config,
         [
             "pgtools",
             "pg_activity",
@@ -148,7 +150,8 @@ def _psql(
         ]
 
         if use_docker_container or (config.use_docker and config.run_postgres):
-            __dcrun(config, 
+            __dcrun(
+                config,
                 ["pgtools", bin] + cmd,
                 interactive=interactive,
                 env={
@@ -217,15 +220,9 @@ def anonymize(ctx, config):
         click.secho("Either DEVMODE or force required", fg="red")
         sys.exit(-1)
 
-    # Commands.invoke(
-    #     ctx,
-    #     'update',
-    #     module=['anonymize'],
-    #     no_restart=False,
-    #     no_dangling_check=True,
-    #     no_update_module_list=False,
-    #     non_interactive=True,
-    # )
+    _make_sure_module_is_installed(
+        ctx, config, "anonymize", "https://github.com/marcwimmer/odoo-anonymize.git"
+    )
 
     Commands.invoke(
         ctx,
@@ -246,6 +243,10 @@ def cleardb(ctx, config, no_update):
         click.secho("Either DEVMODE or force required", fg="red")
         sys.exit(-1)
 
+    _make_sure_module_is_installed(
+        ctx, config, "cleardb", "https://github.com/marcwimmer/odoo-cleardb.git"
+    )
+
     if not no_update:
         Commands.invoke(
             ctx,
